---
sidebar_position: 10
---

import RTCTableTypes from '/docs/partials/guides/_table-livestream-meeting.mdx';

# 服务介绍

融云的实时音视频平台构建于 WebRTC 之上，使您能够将实时音视频功能构建到您的 Web 和移动应用程序中。使用融云的 REST API 和客户端 SDK，您可以获取、传输和播放媒体，并管理应用程序中的网络连接。

## 支持的平台

目前支持以下平台：

- **移动设备** ：Android (Java/Kotlin)、iOS (Objective-C/Swift)、Flutter、uni-app、React Native
- **Web** ：Javascript
- **桌面** ：Electron

## 用例

实时视频应用程序可用于广泛的应用程序和用例，包括：

- 虚拟面试
- 线上课堂
- 远程协作
- 远程医疗
- 远程面签
- 直播社交
- 网络研讨会
- 虚拟活动（网络发布会）

## 主要特点

融云会议、直播产品提供一系列功能，包括视频大小流、美声特效、屏幕共享、云端录制、详细的通话分析等。

<RTCTableTypes></RTCTableTypes>

RTC 服务支持的高级与扩展功能，包括但不限于以下项目：

- **自定义过滤器** ：构建您自己的音频/视频过滤器，类似于 Snapchat 或会说话的汤姆过滤器，添加有趣的效果，如复古风格、生日主题或有趣的帽子，为参与者创造引人入胜的独特体验。
- **屏幕共享**：通过自定义视频流的方式在房间内发起屏幕共享功能。
- **自定义加密**：可选择对媒体流进行加密，从而保障用户的数据安全。
- **美颜特效** ：使用融云官方的美声特效插件，添加有趣的声音特质、变声和混响效果，如低沉、绿巨人、演唱会等，为参与者创造引人入胜的独特体验。
- **美声特效** ：使用融云官方或第三方的美颜插件，设置美白、亮度等参数，或添加各类滤镜。
- **对接第三方插件**：您可以通过 SDK 提供的视频帧数据回调接口，自行对接第三方 SDK。
- **网络探测**：在加入音视频房间前进行网络质量探测，然后通过回调将当前网络质量的相关数据，包括往返时延、上下行丢包率、上下行网络带宽等数据返回给上层应用。
- **媒体补充增强信息**：支持推流端发送自定义的媒体补充增强信息（SEI），实现更多的自定义功能。一般可用于视频画面的精准布局、远端歌词同步、直播答题等应用场景。
- **云端录制**：在音视频通话（呼叫）、直播、会议时分别录制每个参与者的音视频、或合并后进行录制。
- **内容审核**：融云媒体服务器（RTC Server）把收到的音视频流转码后送审，审核结果返回应用服务器。
- **旁路推流**：直播模式下，支持将融云实时音视频流转为 rtmp 流媒体协议，推流到 CDN 服务。

部分功能需配合 RTC 服务端 API 使用。具体支持的功能与平台相关。具体使用方法请参见客户端 SDK 开发文档或服务端开发文档。

## 服务端

您的后端可利用融云服务端提供的 RTC Server API 执行以下操作：

- [查询音视频房间人员与资源](/server-rtc-api/user/query)
- [将参与者踢出音视频房间](/server-rtc-api/user/kick)
- [开始录制](/server-rtc-api/record/start)等

部分高级扩展特性仅在 RTC Server API 中提供，例如云端截图、云播放器等。

## 客户端

您的应用程序通过集成 RTCLib SDK、CallLib SDK 和其他 UI 库来连接到融云服务、传输消息即时消息、以及构建其他功能。

- **音视频核心 SDK** ：[RTCLib SDK] 旨在提供一种整合实时音视频通信 (RTC) 能力的简单方案。借助 RTCLib SDK 封装的音视频通信能力和音视频流、房间等对象，您可以从头开始构建自己的会议、直播应用程序的 UI。
- **呼叫 SDK** ：[CallLib SDK]，[CallPlus SDK] 是基于核心 SDK 实现的呼叫 SDK，封装了拨打、振铃、接听、挂断等一整套呼叫流程，支持一对一及多人呼叫的通话能力。您可以基于 CallLib SDK 或 CallPlus SDK 从头开始构建自己的呼叫 UI，无需处理复杂的 RTCLib 层的 API。
- **呼叫 UI 库** ：[CallKit] 是 UI 组件库，集成了呼叫界面，可简化您的集成体验。

## 控制台

[控制台](https://console.rongcloud.cn/)作为一个综合服务平台，提供对 App Key、App secret、计费操作和各种其他功能配置的一站式访问与管理能力。

您还可以使用控制台调试 IM Server API、查询消息状态、查询连接状态、添加 Webhook 等等。

![开发门户|600x300](/static/guides/dev-portal-config.png)

## 数据与隐私

您可以前往控制台的[数据统计页面](https://console.rongcloud.cn/agile/formwork/stat/index)，查询、查看音视频用量、业务健康检查等数据。开通相应服务后，还能获取如业务数据分析等数据。

融云还提供通话质量实时的监控工具，以图表形式展示每一通音视频通话的质量数据，帮助定位通话问题，提高问题解决效率。

融云不会利用客户的数据。同时融云提供完善的数据隐私保护策略。参见 [SDK 隐私政策]。

[RTCLib SDK]: ../../sdk-libraries/client-sdks/rtclib.md
[CallLib SDK]: ../../sdk-libraries/client-sdks/calllib.md
[CallPlus SDK]: ../../sdk-libraries/client-sdks/callplus.md
[CallKit]: ../../sdk-libraries/client-sdks/callkit.md
[音视频通话]: https://www.rongcloud.cn/product/call
[音视频会议]: https://www.rongcloud.cn/product/meeting
[低延迟直播]: https://www.rongcloud.cn/product/live
[SDK 隐私政策]: /guides/privacy
